@@ -10,7 +10,7 @@ from . import compactmodel_io
 from . import dtm
 
 from .textpreprocessing import tokenize, stemword
-from .textpreprocessing import text_preprocessor, standard_text_preprocessor_1
+from .textpreprocessing import text_preprocessor, standard_text_preprocessor_1, standard_text_preprocessor_2
 
 from .wordembed import load_word2vec_model, load_fasttext_model, load_poincare_model, shorttext_to_avgvec
 from .wordembed import RESTfulKeyedVectors
